@@ -53,6 +53,28 @@ class StateMachine():
     def verbose(self, val):
         self._verbose = val
 
+    def on_line(line):
+        pass
+
+    def leave_and_loop(self, lines_getter):
+        """まず state_machine.leave(...) を行い、
+        そのあと arrive(...), leave(...) のペアを無限に繰り返します。
+        leave(...) に渡す line 引数は、
+        lines_getter() を実行することでリストで取得できるようにしてください。
+        lines_getter() が None を返すとループを抜けます"""
+        while True:
+            lines = lines_getter()
+            if not lines:
+                break
+
+            for line in lines:
+
+                self.on_line(line)
+
+                next_state_name, transition_key = self.leave(
+                    line)
+                self.arrive_sequence(next_state_name)
+
     def arrive_sequence(self, next_state_name):
         """arrive(next_state_name) の拡張版。
         このステートを通り過ぎる指定があったなら、次の leave(...) まで行います。
